summaryrefslogtreecommitdiffstats
path: root/src/dolphincontextmenu.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphincontextmenu.h')
-rw-r--r--src/dolphincontextmenu.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/dolphincontextmenu.h b/src/dolphincontextmenu.h
index 1b0a0c9..52e6897 100644
--- a/src/dolphincontextmenu.h
+++ b/src/dolphincontextmenu.h
@@ -54,14 +54,14 @@ class DolphinContextMenu
{
public:
/**
* @tqparent Pointer to the dolphin view the context menu
* belongs to.
* @fileInfo Pointer to the file item the context menu
* is applied. If 0 is passed, the context menu
* is above the viewport.
* @pos Position of the upper left edge of the context menu.
*/
- DolphinContextMenu(DolphinView* tqparent,
+ DolphinContextMenu(DolphinView* parent,
KFileItem* fileInfo,
const TQPoint& pos);
@@ -54,14 +54,14 @@ class DolphinContextMenu
public:
/**
- * @tqparent Pointer to the dolphin view the context menu
+ * @parent Pointer to the dolphin view the context menu
* belongs to.
* @fileInfo Pointer to the file item the context menu